==> neumorphic-0.0.2%2B1.tar.gz: README.md <==
# neumorphic

Neumorphic Ui for flutter

![NeumorphicStatus](https://miro.medium.com/max/1024/1*EET5FBkpc738Xi75pgrH1w.png)

Includes two states:
`NeumorphicStatus.convex` (first) & 
`NeumorphicStatus.concave` (second)

## Api
Now implemented some widgets:

 - Neumorphic
 - NeumorphicButton
 - NeumorphicSwitch

### Neumorphic
It is container like a `Material` merged with `Container`, but implement Neumorphism

```dart
Neumorphic(
  // State of Neumorphic (may be concave & convex)
  status: NeumorphicStatus.concave,

  // Elevation relative to parent. Main constituent of Neumorphism
  bevel: 10,

  // Specified decorations, like `BoxDecoration` but only limited
  decoration: NeumorphicDecoration(
    borderRadius: BorderRadius.circular(8)
  ),

  // Other arguments such as margin, padding etc. (Like `Container`)
  child: Text('Container')
)
```

### NeumorphicButton
Button automatically when pressed toggle the status of NeumorphicStatus from `concave` to `convex` and back
```dart
NeumorphicButton(
  onPressed: () {
    print('Pressed !');
  },
  child: Text('Button'),
);
```

### NeumorphicSwitch
Remade `CupertinoSlidingSegmentedControl`
```dart
NeumorphicSwitch<int>(
  onValueChanged: (val) {
    setState(() {
      switchValue = val;
    });
  },
  groupValue: switchValue,
  children: {
    0: Padding(
      padding: EdgeInsets.symmetric(vertical: 24, horizontal: 8),
      child: Text('First'),
    ),
    1: Padding(
      padding: EdgeInsets.symmetric(vertical: 24, horizontal: 8),
      child: Text('Second'),
    ),
  },
);
```

## Getting Started

This project is a starting point for a Flutter
[plug-in package](https://flutter.dev/developing-packages/),
a specialized package that includes platform-specific implementation code for
Android and/or iOS.

For help getting started with Flutter, view our 
[online documentation](https://flutter.dev/docs), which offers tutorials, 
samples, guidance on mobile development, and a full API reference.

## Inspired by

1) [Alexander Plyuto (figma)](https://www.figma.com/file/J1uPSOY5k577mDpSfGFven/Skeuomorph-Small-Style-Guide)

2) [Ivan Cherepanov (medium)](https://medium.com/flutter-community/neumorphic-designs-in-flutter-eab9a4de2059)

==> neumorphic-0.1.1%2B1.tar.gz: README.md <==
# Neumorphic Ui kit for flutter

|   |   |
| --- | --- |
|![showcase](https://raw.githubusercontent.com/neumorphic/neumorphic.flutter/master/example/media/v0/all.gif)|![cards](https://raw.githubusercontent.com/neumorphic/neumorphic.flutter/master/example/media/v0/cards.png)|


## Getting Started

In your flutter project add the dependency:

[![pub package](https://img.shields.io/pub/v/neumorphic.svg)](https://pub.dev/packages/neumorphic)

```yaml
dependencies:
  neumorphic: any
```

For help getting started with Flutter, view the online [documentation](https://flutter.io/).

## Api
Now implemented some widgets:

 - NeuCard
 - NeuButton
 - NeuSwitch

### NeuCard
It is container like a `Material` merged with `Container`, but implement Neumorphism

```dart
NeuCard(
  // State of Neumorphic (may be convex, flat & emboss)
  curveType: CurveType.concave,

  // Elevation relative to parent. Main constituent of Neumorphism
  bevel: 12,

  // Specified decorations, like `BoxDecoration` but only limited
  decoration: NeumorphicDecoration(
    borderRadius: BorderRadius.circular(8)
  ),

  // Other arguments such as margin, padding etc. (Like `Container`)
  child: Text('Container')
)
```

### NeuButton
Button automatically when pressed toggle the status of NeumorphicStatus from `concave` to `convex` and back
```dart
NeuButton(
  onPressed: () {
    print('Pressed !');
  },
  child: Text('Button'),
);
```

### NeuSwitch
Remade `CupertinoSlidingSegmentedControl`
```dart
NeuSwitch<int>(
  onValueChanged: (val) {
    setState(() {
      switchValue = val;
    });
  },
  groupValue: switchValue,
  children: {
    0: Padding(
      padding: EdgeInsets.symmetric(vertical: 24, horizontal: 8),
      child: Text('First'),
    ),
    1: Padding(
      padding: EdgeInsets.symmetric(vertical: 24, horizontal: 8),
      child: Text('Second'),
    ),
  },
);
```

## Inspired by

1) [Alexander Plyuto (figma)](https://www.figma.com/file/J1uPSOY5k577mDpSfGFven/Skeuomorph-Small-Style-Guide)

2) [Ivan Cherepanov (medium)](https://medium.com/flutter-community/neumorphic-designs-in-flutter-eab9a4de2059)
